@@ -14,11 +14,12 @@ All of the API requests are created, and the API responses are parsed here.
 
 """
 
-__version__ = '0.2.10'
+__version__ = '0.2.11'
 
 import functools
 import json
 import requests
+import time
 
 DEFAULT_TIMEOUT = 10  # seconds
 
@@ -35,6 +36,11 @@ class AuthenticationError(IntercomError):
     pass
 
 
+class BadGatewayError(IntercomError):
+    """ Raised when a request does not reach the API due to a 502. """
+    pass
+
+
 class ResourceNotFound(IntercomError):
     """ Raised when a resource cannot be found e.g. a non-existant User. """
     pass
@@ -46,30 +52,38 @@ class ServerError(IntercomError):
     pass
 
 
+class ServiceUnavailableError(IntercomError):
+    """ Raised when the API cannot be handle a request. """
+    pass
+
+
 def api_call(func_to_decorate):
     """ Decorator for handling AWS credentials. """
     @functools.wraps(func_to_decorate)
     def wrapper(*args, **kwargs):
         """ Decorator closure. """
         response = func_to_decorate(*args, **kwargs)
-        if response.status_code == 401:
-            raise AuthenticationError("Invalid API key/username provided.")
-        try:
-            result = json.loads(response.content)
-        except ValueError as err:
-            raise ServerError(err.message)
-        if response.status_code in (200, 201):
-            pass
-        else:
-            message = result['error']['message']
-            if response.status_code == 404:
-                raise ResourceNotFound(message, result)
-            else:
-                raise ServerError(message, result)
+        raise_errors_on_failure(response)
+        if not response.content.strip():
+            return ''
+        result = json.loads(response.content)
         return result
     return wrapper
 
 
+def raise_errors_on_failure(response):
+    if response.status_code == 404:
+        raise ResourceNotFound("Not found.")
+    elif response.status_code == 401:
+        raise AuthenticationError("Invalid API key/username provided.")
+    elif response.status_code == 500:
+        raise ServerError("Server error.")
+    elif response.status_code == 502:
+        raise BadGatewayError("Bad gateway.")
+    elif response.status_code == 503:
+        raise ServiceUnavailableError("Service unavailable.")
+
+
 class Intercom(object):
     """ Intercom API Wrapper """
 
@@ -110,19 +124,24 @@ class Intercom(object):
 
     @classmethod
     def get_users(cls, **kwargs):
-        """ Returns a paginated list of all users in your application on Intercom.
+        """ Returns a paginated list of all users in your application on
+        Intercom.
 
         **Arguments**
 
         * ``page``: optional (defaults to 1)
         * ``per_page``: optional (defaults to 500, max value of 500)
-        * ``tag_id``: optional — query for users that are tagged with a specific tag.
-        * ``tag_name``: optional — query for users that are tagged with a specific tag.
+        * ``tag_id``: optional — query for users that are tagged with a
+          specific tag.
+        * ``tag_name``: optional — query for users that are tagged with a
+          specific tag.
 
         **Response**
 
-        * ``users``: an array of User objects (same as returned by getting a single User)
-        * ``total_count``: the total number of Users tracked in your Intercom application
+        * ``users``: an array of User objects (same as returned by getting a
+          single User)
+        * ``total_count``: the total number of Users tracked in your Intercom
+          application
         * ``page``: the current requested page
         * ``next_page``: the next page number, if any
         * ``previous_page``: the previous page number, if any
@@ -135,7 +154,8 @@ class Intercom(object):
         3
 
         """
-        return Intercom._call('GET', Intercom.api_endpoint + 'users', params=kwargs)
+        return Intercom._call(
+            'GET', Intercom.api_endpoint + 'users', params=kwargs)
 
     @classmethod
     def get_user(cls, email=None, user_id=None):
@@ -144,7 +164,7 @@ class Intercom(object):
 
         >>> user = Intercom.get_user(user_id='123')
         >>> user['name']
-        u'Bob'
+        u'Somebody'
 
         """
 
@@ -183,16 +203,14 @@ class Intercom(object):
           unsubscribed status.
 
 
-        >>> from datetime import datetime
-        >>> import time
-        >>> now = time.mktime(datetime.now().timetuple())
-        >>> user = Intercom.create_user(user_id='7902', email='ben@intercom.io',
-        ... name='Ben McRedmond', created_at=now, last_seen_ip='1.2.3.4',
-        ... custom_data={ 'plan': 'pro'}, last_request_at=1300000000)
+        >>> user = Intercom.create_user(user_id='7902',
+        ... email='ben@intercom.io',
+        ... name='Somebody', created_at=1270000000, last_seen_ip='1.2.3.4',
+        ... custom_data={ 'app_name': 'Genesis'}, last_request_at=1300000000)
         >>> user['name']
-        u'Ben McRedmond'
-        >>> user['custom_data']['plan']
-        u'pro'
+        u'Somebody'
+        >>> user['custom_data']['app_name']
+        u'Genesis'
         >>> user['last_impression_at']
         1300000000
 
@@ -205,10 +223,10 @@ class Intercom(object):
 
         >>> user = Intercom.get_user(user_id='123')
         >>> user['name']
-        u'Bob'
-        >>> user = Intercom.update_user(user_id='123', name='Han')
+        u'Somebody'
+        >>> user = Intercom.update_user(user_id='123', name='Guido')
         >>> user['name']
-        u'Han'
+        u'Guido'
 
         """
         return Intercom._create_or_update_user('PUT', **kwargs)
@@ -217,9 +235,9 @@ class Intercom(object):
     def delete_user(cls, user_id=None, email=None):
         """ Delete a user.
 
-        >>> user = Intercom.get_user(user_id='7902')
+        >>> user = Intercom.get_user(user_id='123')
         >>> user['email']
-        u'bob@example.com'
+        u'somebody@example.com'
 
         """
         params = {
@@ -258,9 +276,9 @@ class Intercom(object):
         """ Create a note.
 
         >>> result = Intercom.create_note(email="somebody@example.com",
-        ... body="This is the text of my note.")
+        ... body="This is a note")
         >>> result['html']
-        u'<p>This is the text of my note.</p>'
+        u'<p>This is a note</p>'
         >>> result['user']['email']
         u'somebody@example.com'
 
@@ -306,13 +324,13 @@ class Intercom(object):
 
         >>> message_thread = Intercom.create_message_thread(
         ... email="somebody@example.com",
-        ... body="Uh, everything's under control. Situation normal.")
+        ... body="Hey Intercom, What is up?")
         >>> message_thread['thread_id']
         5591
         >>> len(message_thread['messages'])
-        1
+        3
         >>> message_thread['messages'][0]['html']
-        u"<p>Uh, everything's under control. Situation normal.</p>"
+        u'<p>Hey Intercom, What is up?</p>\n\n<p></p>'
 
         """
         params = {
@@ -425,3 +443,22 @@ class Intercom(object):
         tag_dict = Intercom._call(
             'GET', Intercom.api_endpoint + 'tags', params=params)
         return tag_dict
+
+    @classmethod
+    def create_event(cls, event_name=None, user_id=None, email=None, metadata=None):
+        """
+        Create an event
+        """
+        params = {
+            'event_name': event_name,
+            'user_id': user_id,
+            'email': email,
+            'created': int(time.time()) 
+         }
+
+        if isinstance(metadata, dict):
+            params['metadata'] = metadata
+
+        call = Intercom._call(
+             'POST', Intercom.api_endpoint + 'events', params=params)
+        return call
