@@ -15,6 +15,7 @@
 
 from . import Intercom
 from . import from_timestamp_property
+from . import to_timestamp_property
 from .user import User
 from .user import UserId
 
@@ -27,10 +28,11 @@ class Note(UserId):
         """ Create a Note.
 
         >>> note = Note.create(email="somebody@example.com",
-        ...        body="This is the text of my note.")
-        >>> note['created_at']
+        ...        body="This is a note.")
+        >>> note.created_at.year
+        2011
         >>> note.html
-        u'<p>This is the text of my note.</p>'
+        u'<p>This is a note</p>'
 
         """
         resp = Intercom.create_note(user_id=user_id, email=email, body=body)
@@ -41,10 +43,10 @@ class Note(UserId):
 
         >>> note = Note()
         >>> note.email = "somebody@example.com"
-        >>> note.body = "This is the text of my note."
+        >>> note.body = "This is a note."
         >>> note.save()
         >>> note.html
-        u'<p>This is the text of my note.</p>'
+        u'<p>This is a note</p>'
 
         """
         resp = Intercom.create_note(
@@ -73,6 +75,12 @@ class Note(UserId):
         API response. """
         return dict.get(self, 'created_at', None)
 
+    @created_at.setter
+    @to_timestamp_property
+    def created_at(self, created_at):
+        """ Set the datetime this note was created. """
+        self['created_at'] = created_at
+
     @property
     def user(self):
         """ Get the noted user – set by an API response. """
